@@ -120,6 +120,9 @@ public class StatisticTools extends AbstractJMXTools {
     private static final char OPT_DOCUMENTCONVERTER_STATS_SHORT = 'y';
     private static final String OPT_DOCUMENTCONVERTER_STATS_LONG = "documentconverterstats";
 
+    private static final char OPT_OFFICE_STATS_SHORT = 'f';
+    private static final String OPT_OFFICE_STATS_LONG = "officestats";
+
     private CLIOption xchangestats = null;
     private CLIOption threadpoolstats = null;
     private CLIOption runtimestats = null;
@@ -135,6 +138,7 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption clusterStats = null;
     private CLIOption grizzlyStats = null;
     private CLIOption documentconverterstats = null;
+    private CLIOption officestats = null;
 
     /**
      * Option for garbage collection statistics
@@ -228,6 +232,10 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showDocumentConverterData(mbc));
             count++;
         }
+        if (null != parser.getOptionValue(this.officestats) && 0 == count) {
+            System.out.print(showOfficeData(mbc));
+            count++;
+        }
         if (0 == count) {
             System.err.println(new StringBuilder("No option selected (").append(OPT_STATS_LONG).append(", ").append(
                 OPT_RUNTIME_STATS_LONG).append(", ").append(OPT_OS_STATS_LONG).append(", ").append(OPT_THREADING_STATS_LONG).append(
@@ -447,6 +455,13 @@ public class StatisticTools extends AbstractJMXTools {
             "shows the documentconverter stats",
             false,
             NeededQuadState.notneeded);
+        this.officestats = setShortLongOpt(
+            parser,
+            OPT_OFFICE_STATS_SHORT,
+            OPT_OFFICE_STATS_LONG,
+            "shows the office stats",
+            false,
+            NeededQuadState.notneeded);
     }
 
     static String showMemoryPoolData(MBeanServerConnection con) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException, MalformedObjectNameException, NullPointerException {
@@ -594,6 +609,10 @@ public class StatisticTools extends AbstractJMXTools {
         return getStats(mbeanServerConnection, "com.openexchange.documentconverter:name=DocumentConverterInformation").toString();
     }
 
+    static String showOfficeData(final MBeanServerConnection mbeanServerConnection) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException, MalformedObjectNameException, NullPointerException {
+        return getStats(mbeanServerConnection, "com.openexchange.office:name=OfficeMonitoring").toString();
+    }
+
     /**
      * Method to prepare and display the garbage collection information.
      *
