@@ -49,63 +49,103 @@
 
 package com.openexchange.admin.console.util.database;
 
+import java.net.URI;
+import java.net.URISyntaxException;
 import com.openexchange.admin.console.AdminParser;
-import com.openexchange.admin.console.CLIOption;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
+import com.openexchange.admin.console.CLIOption;
 import com.openexchange.admin.console.util.UtilAbstraction;
 import com.openexchange.admin.rmi.dataobjects.Database;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 
 /**
  * This is an abstract class for all common attributes and methods of database related command line tools
- *
+ * 
  * @author d7
- *
  */
-public abstract class DatabaseAbstraction extends UtilAbstraction{
+public abstract class DatabaseAbstraction extends UtilAbstraction {
+
     protected static final char OPT_NAME_DATABASE_ID_SHORT = 'i';
+
     protected static final String OPT_NAME_DATABASE_ID_LONG = "id";
+
     protected final static char OPT_NAME_DB_USERNAME_SHORT = 'u';
+
     protected final static String OPT_NAME_DB_USERNAME_LONG = "dbuser";
+
     protected final static char OPT_NAME_DBNAME_SHORT = 'n';
+
     protected final static String OPT_NAME_DBNAME_LONG = "name";
+
     protected final static char OPT_NAME_DB_PASSWD_SHORT = 'p';
+
     protected final static String OPT_NAME_DB_PASSWD_LONG = "dbpasswd";
+
     protected final static char OPT_NAME_POOL_HARDLIMIT_SHORT = 'l';
+
     protected final static String OPT_NAME_POOL_HARDLIMIT_LONG = "poolhardlimit";
+
     protected final static char OPT_NAME_POOL_INITIAL_SHORT = 'o';
+
     protected final static String OPT_NAME_POOL_INITIAL_LONG = "poolinitial";
+
     protected final static char OPT_NAME_POOL_MAX_SHORT = 'a';
+
     protected final static String OPT_NAME_POOL_MAX_LONG = "poolmax";
+
     protected final static char OPT_NAME_DB_DRIVER_SHORT = 'd';
+
     protected final static String OPT_NAME_DB_DRIVER_LONG = "dbdriver";
+
     protected final static char OPT_NAME_MASTER_ID_SHORT = 'M';
+
     protected final static String OPT_NAME_MASTER_ID_LONG = "masterid";
+
     protected final static char OPT_NAME_WEIGHT_SHORT = 'w';
+
     protected final static String OPT_NAME_WEIGHT_LONG = "dbweight";
+
     protected final static char OPT_NAME_MAX_UNITS_SHORT = 'x';
+
     protected final static String OPT_NAME_MAX_UNITS_LONG = "maxunit";
+
     protected final static char OPT_NAME_HOSTNAME_SHORT = 'H';
+
     protected final static String OPT_NAME_HOSTNAME_LONG = "hostname";
+
     protected final static char OPT_NAME_IS_MASTER_SHORT = 'm';
+
     protected final static String OPT_NAME_IS_MASTER_LONG = "master";
 
     protected CLIOption databaseIdOption = null;
+
     protected CLIOption databaseUsernameOption = null;
+
     protected CLIOption databaseDriverOption = null;
+
     protected CLIOption databasePasswdOption = null;
+
     protected CLIOption databaseIsMasterOption = null;
+
     protected CLIOption databaseMasterIDOption = null;
+
     protected CLIOption databaseWeightOption = null;
+
     protected CLIOption databaseNameOption = null;
+
     protected CLIOption hostnameOption = null;
+
     protected CLIOption maxUnitsOption = null;
+
     protected CLIOption poolHardlimitOption = null;
+
     protected CLIOption poolInitialOption = null;
+
     protected CLIOption poolMaxOption = null;
 
     // Needed for right error output
     protected String dbid = null;
+
     protected String dbname = null;
 
     protected void parseAndSetDatabaseID(final AdminParser parser, final Database db) {
@@ -122,10 +162,20 @@ public abstract class DatabaseAbstraction extends UtilAbstraction{
         }
     }
 
-    private void parseAndSetHostname(final AdminParser parser, final Database db) {
-        final String hostname = (String)parser.getOptionValue(this.hostnameOption);
+    private void parseAndSetHostname(final AdminParser parser, final Database db) throws InvalidDataException {
+        String hostname = (String) parser.getOptionValue(this.hostnameOption);
         if (null != hostname) {
-            db.setUrl("jdbc:mysql://" + hostname + "/?useUnicode=true&characterEncoding=UTF-8&autoReconnect=true&useUnicode=true&useServerPrepStmts=false&useTimezone=true&serverTimezone=UTC&connectTimeout=15000&socketTimeout=15000");
+            if (hostname.startsWith("mysql://")) {
+                URI uri;
+                try {
+                    uri = new URI(hostname);
+                    int port = uri.getPort();
+                    hostname = uri.getHost() + String.valueOf(port != -1 ? port : 3306);
+                } catch (URISyntaxException e) {
+                    throw new InvalidDataException(e);
+                }
+            }
+            db.setUrl("jdbc:mysql://" + hostname + "/?useUnicode=true&characterEncoding=UTF-8&autoReconnect=false&useUnicode=true&useServerPrepStmts=false&useTimezone=true&serverTimezone=UTC&connectTimeout=15000&socketTimeout=15000");
         }
     }
 
@@ -212,80 +262,200 @@ public abstract class DatabaseAbstraction extends UtilAbstraction{
     }
 
     protected void setDatabaseIDOption(final AdminParser parser) {
-        this.databaseIdOption = setShortLongOpt(parser, OPT_NAME_DATABASE_ID_SHORT,OPT_NAME_DATABASE_ID_LONG,"The id of the database.",true, NeededQuadState.eitheror);
+        this.databaseIdOption = setShortLongOpt(
+            parser,
+            OPT_NAME_DATABASE_ID_SHORT,
+            OPT_NAME_DATABASE_ID_LONG,
+            "The id of the database.",
+            true,
+            NeededQuadState.eitheror);
     }
 
     protected void setDatabasePoolMaxOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
-            this.poolMaxOption = setShortLongOptWithDefault(parser, OPT_NAME_POOL_MAX_SHORT, OPT_NAME_POOL_MAX_LONG, "Db pool max", defaultvalue, true, convertBooleantoTriState(required));
+            this.poolMaxOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_POOL_MAX_SHORT,
+                OPT_NAME_POOL_MAX_LONG,
+                "Db pool max",
+                defaultvalue,
+                true,
+                convertBooleantoTriState(required));
         } else {
-            this.poolMaxOption = setShortLongOpt(parser, OPT_NAME_POOL_MAX_SHORT, OPT_NAME_POOL_MAX_LONG, "Db pool max", true, convertBooleantoTriState(required));
+            this.poolMaxOption = setShortLongOpt(
+                parser,
+                OPT_NAME_POOL_MAX_SHORT,
+                OPT_NAME_POOL_MAX_LONG,
+                "Db pool max",
+                true,
+                convertBooleantoTriState(required));
         }
     }
 
     protected void setDatabasePoolInitialOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
-            this.poolInitialOption = setShortLongOptWithDefault(parser, OPT_NAME_POOL_INITIAL_SHORT, OPT_NAME_POOL_INITIAL_LONG, "Db pool initial", defaultvalue, true, convertBooleantoTriState(required));
+            this.poolInitialOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_POOL_INITIAL_SHORT,
+                OPT_NAME_POOL_INITIAL_LONG,
+                "Db pool initial",
+                defaultvalue,
+                true,
+                convertBooleantoTriState(required));
         } else {
-            this.poolInitialOption = setShortLongOpt(parser, OPT_NAME_POOL_INITIAL_SHORT, OPT_NAME_POOL_INITIAL_LONG, "Db pool initial", true, convertBooleantoTriState(required));
+            this.poolInitialOption = setShortLongOpt(
+                parser,
+                OPT_NAME_POOL_INITIAL_SHORT,
+                OPT_NAME_POOL_INITIAL_LONG,
+                "Db pool initial",
+                true,
+                convertBooleantoTriState(required));
         }
     }
 
-    protected void setDatabaseHostnameOption(final AdminParser parser,final boolean required){
-        this.hostnameOption =  setShortLongOpt(parser, OPT_NAME_HOSTNAME_SHORT,OPT_NAME_HOSTNAME_LONG,"Hostname of the server",true, convertBooleantoTriState(required));
+    protected void setDatabaseHostnameOption(final AdminParser parser, final boolean required) {
+        this.hostnameOption = setShortLongOpt(
+            parser,
+            OPT_NAME_HOSTNAME_SHORT,
+            OPT_NAME_HOSTNAME_LONG,
+            "Hostname of the server",
+            true,
+            convertBooleantoTriState(required));
     }
 
-    protected void setDatabaseUsernameOption(final AdminParser parser,final boolean required){
-        this.databaseUsernameOption = setShortLongOpt(parser, OPT_NAME_DB_USERNAME_SHORT,OPT_NAME_DB_USERNAME_LONG,"Name of the user for the database",true, convertBooleantoTriState(required));
+    protected void setDatabaseUsernameOption(final AdminParser parser, final boolean required) {
+        this.databaseUsernameOption = setShortLongOpt(
+            parser,
+            OPT_NAME_DB_USERNAME_SHORT,
+            OPT_NAME_DB_USERNAME_LONG,
+            "Name of the user for the database",
+            true,
+            convertBooleantoTriState(required));
     }
 
     protected void setDatabaseDriverOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
-            this.databaseDriverOption = setShortLongOptWithDefault(parser, OPT_NAME_DB_DRIVER_SHORT, OPT_NAME_DB_DRIVER_LONG, "The driver to be used for the database", defaultvalue, true, convertBooleantoTriState(required));
+            this.databaseDriverOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_DB_DRIVER_SHORT,
+                OPT_NAME_DB_DRIVER_LONG,
+                "The driver to be used for the database",
+                defaultvalue,
+                true,
+                convertBooleantoTriState(required));
         } else {
-            this.databaseDriverOption = setShortLongOpt(parser, OPT_NAME_DB_DRIVER_SHORT,OPT_NAME_DB_DRIVER_LONG,"The driver to be used for the database",true, convertBooleantoTriState(required));
+            this.databaseDriverOption = setShortLongOpt(
+                parser,
+                OPT_NAME_DB_DRIVER_SHORT,
+                OPT_NAME_DB_DRIVER_LONG,
+                "The driver to be used for the database",
+                true,
+                convertBooleantoTriState(required));
         }
     }
 
-    protected void setDatabasePasswdOption(final AdminParser parser,final boolean required){
-        this.databasePasswdOption = setShortLongOpt(parser, OPT_NAME_DB_PASSWD_SHORT,OPT_NAME_DB_PASSWD_LONG,"Password for the database",true, convertBooleantoTriState(required));
+    protected void setDatabasePasswdOption(final AdminParser parser, final boolean required) {
+        this.databasePasswdOption = setShortLongOpt(
+            parser,
+            OPT_NAME_DB_PASSWD_SHORT,
+            OPT_NAME_DB_PASSWD_LONG,
+            "Password for the database",
+            true,
+            convertBooleantoTriState(required));
     }
 
-    protected void setDatabaseIsMasterOption(final AdminParser parser,final boolean required){
-        this.databaseIsMasterOption = setShortLongOpt(parser, OPT_NAME_IS_MASTER_SHORT, OPT_NAME_IS_MASTER_LONG, "true/false", "Set this if the registered database is the master", required);
+    protected void setDatabaseIsMasterOption(final AdminParser parser, final boolean required) {
+        this.databaseIsMasterOption = setShortLongOpt(
+            parser,
+            OPT_NAME_IS_MASTER_SHORT,
+            OPT_NAME_IS_MASTER_LONG,
+            "true/false",
+            "Set this if the registered database is the master",
+            required);
     }
 
-    protected void setDatabaseMasterIDOption(final AdminParser parser,final boolean required){
-        this.databaseMasterIDOption = setShortLongOpt(parser, OPT_NAME_MASTER_ID_SHORT, OPT_NAME_MASTER_ID_LONG, "If this database isn't the master give the id of the master here", true, convertBooleantoTriState(required));
+    protected void setDatabaseMasterIDOption(final AdminParser parser, final boolean required) {
+        this.databaseMasterIDOption = setShortLongOpt(
+            parser,
+            OPT_NAME_MASTER_ID_SHORT,
+            OPT_NAME_MASTER_ID_LONG,
+            "If this database isn't the master give the id of the master here",
+            true,
+            convertBooleantoTriState(required));
     }
 
     protected void setDatabaseWeightOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
-            this.databaseWeightOption = setShortLongOptWithDefault(parser, OPT_NAME_WEIGHT_SHORT, OPT_NAME_WEIGHT_LONG, "The db weight for this database", defaultvalue, true, convertBooleantoTriState(required));
+            this.databaseWeightOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_WEIGHT_SHORT,
+                OPT_NAME_WEIGHT_LONG,
+                "The db weight for this database",
+                defaultvalue,
+                true,
+                convertBooleantoTriState(required));
         } else {
-            this.databaseWeightOption = setShortLongOpt(parser, OPT_NAME_WEIGHT_SHORT, OPT_NAME_WEIGHT_LONG, "The db weight for this database", true, convertBooleantoTriState(required));
+            this.databaseWeightOption = setShortLongOpt(
+                parser,
+                OPT_NAME_WEIGHT_SHORT,
+                OPT_NAME_WEIGHT_LONG,
+                "The db weight for this database",
+                true,
+                convertBooleantoTriState(required));
         }
     }
 
     protected void setDatabaseMaxUnitsOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
-            this.maxUnitsOption = setShortLongOptWithDefault(parser, OPT_NAME_MAX_UNITS_SHORT, OPT_NAME_MAX_UNITS_LONG, "The maximum number of contexts in this database.", defaultvalue, true, convertBooleantoTriState(required));
+            this.maxUnitsOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_MAX_UNITS_SHORT,
+                OPT_NAME_MAX_UNITS_LONG,
+                "The maximum number of contexts in this database.",
+                defaultvalue,
+                true,
+                convertBooleantoTriState(required));
         } else {
-            this.maxUnitsOption = setShortLongOpt(parser, OPT_NAME_MAX_UNITS_SHORT, OPT_NAME_MAX_UNITS_LONG, "The maximum number of contexts in this database.", true, convertBooleantoTriState(required));
+            this.maxUnitsOption = setShortLongOpt(
+                parser,
+                OPT_NAME_MAX_UNITS_SHORT,
+                OPT_NAME_MAX_UNITS_LONG,
+                "The maximum number of contexts in this database.",
+                true,
+                convertBooleantoTriState(required));
         }
     }
 
     protected void setDatabasePoolHardlimitOption(final AdminParser parser, final String defaultvalue, final boolean required) {
         if (null != defaultvalue) {
             // FIXME: choeger Enter right description here
-            this.poolHardlimitOption = setShortLongOptWithDefault(parser, OPT_NAME_POOL_HARDLIMIT_SHORT, OPT_NAME_POOL_HARDLIMIT_LONG, "true/false", "Db pool hardlimit", defaultvalue, required);
+            this.poolHardlimitOption = setShortLongOptWithDefault(
+                parser,
+                OPT_NAME_POOL_HARDLIMIT_SHORT,
+                OPT_NAME_POOL_HARDLIMIT_LONG,
+                "true/false",
+                "Db pool hardlimit",
+                defaultvalue,
+                required);
         } else {
-            this.poolHardlimitOption = setShortLongOpt(parser, OPT_NAME_POOL_HARDLIMIT_SHORT, OPT_NAME_POOL_HARDLIMIT_LONG, "true/false", "Db pool hardlimit", required);
+            this.poolHardlimitOption = setShortLongOpt(
+                parser,
+                OPT_NAME_POOL_HARDLIMIT_SHORT,
+                OPT_NAME_POOL_HARDLIMIT_LONG,
+                "true/false",
+                "Db pool hardlimit",
+                required);
         }
     }
 
-    protected void setDatabaseNameOption(final AdminParser parser, final NeededQuadState required){
-        this.databaseNameOption = setShortLongOpt(parser, OPT_NAME_DBNAME_SHORT,OPT_NAME_DBNAME_LONG,"Name of the database",true, required);
+    protected void setDatabaseNameOption(final AdminParser parser, final NeededQuadState required) {
+        this.databaseNameOption = setShortLongOpt(
+            parser,
+            OPT_NAME_DBNAME_SHORT,
+            OPT_NAME_DBNAME_LONG,
+            "Name of the database",
+            true,
+            required);
     }
 
     @Override
