@@ -49,7 +49,6 @@
 
 package com.openexchange.admin.osgi;
 
-import org.apache.commons.logging.Log;
 import com.openexchange.admin.PluginStarter;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.exceptions.OXGenericException;
@@ -58,8 +57,8 @@ import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.eventsystem.EventSystemService;
 import com.openexchange.i18n.I18nService;
-import com.openexchange.log.LogFactory;
 import com.openexchange.management.ManagementService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.RegistryServiceTrackerCustomizer;
@@ -68,7 +67,7 @@ import com.openexchange.tools.pipesnfilters.PipesAndFiltersService;
 
 public class Activator extends HousekeepingActivator {
 
-    private static final Log LOG = LogFactory.getLog(Activator.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Activator.class);
 
     private PluginStarter starter = null;
 
@@ -83,13 +82,14 @@ public class Activator extends HousekeepingActivator {
         track(I18nService.class, new I18nServiceCustomizer(context));
         track(ManagementService.class, new ManagementCustomizer(context));
         track(PipesAndFiltersService.class, new RegistryServiceTrackerCustomizer<PipesAndFiltersService>(context, AdminServiceRegistry.getInstance(), PipesAndFiltersService.class));
+        track(EventSystemService.class, new RegistryServiceTrackerCustomizer<EventSystemService>(context, AdminServiceRegistry.getInstance(), EventSystemService.class));
         openTrackers();
         this.starter = new PluginStarter();
         try {
             this.starter.start(context, configurationService);
             track(DatabaseService.class, new DatabaseServiceCustomizer(context, ClientAdminThreadExtended.cache.getPool())).open();
         } catch (final OXGenericException e) {
-            LOG.fatal(e.getMessage(), e);
+            LOG.error("", e);
         }
     }
 
