@@ -64,7 +64,6 @@ import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
@@ -95,6 +94,7 @@ import com.openexchange.admin.rmi.exceptions.OXContextException;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtension;
+import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
@@ -104,9 +104,11 @@ import com.openexchange.admin.tools.DatabaseDataMover;
 import com.openexchange.admin.tools.FilestoreDataMover;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
+import com.openexchange.eventsystem.Event;
+import com.openexchange.eventsystem.EventSystemService;
+import com.openexchange.eventsystem.provisioning.ProviosioningEventConstants;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
-import com.openexchange.log.LogFactory;
 import com.openexchange.quota.Resource;
 import com.openexchange.tools.pipesnfilters.Filter;
 
@@ -116,7 +118,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     private static final String SYMBOLIC_NAME_CACHE = "com.openexchange.caching";
 
-    private final Log log = LogFactory.getLog(this.getClass());
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXContext.class);
 
     private final OXAdminPoolDBPoolExtension pool;
 
@@ -124,9 +126,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         super();
         this.context = context;
         this.pool = new OXAdminPoolDBPoolExtension();
-        if (log.isDebugEnabled()) {
-            log.debug("Class loaded: " + this.getClass().getName());
-        }
+            log.debug("Class loaded: {}", this.getClass().getName());
     }
 
     @Override
@@ -162,7 +162,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         final long quota;
-        if (quotaValue <= 0) {
+        if (quotaValue < 0) {
             quota = -1L;
         } else {
             // MySQL int(10) unsigned: the allowable range is from 0 to 4294967295
@@ -172,7 +172,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             quota = quotaValue;
         }
 
-        log.debug(ctx+" - "+modules + " - " + quota);
+        log.debug("{} - {} - {}", ctx, modules, quota);
 
         try {
             if (!tool.existsContext(ctx)) {
@@ -184,10 +184,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
             oxcox.changeQuota(ctx, new ArrayList<String>(modules), quota, auth);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -215,29 +215,46 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchContextException();
             }
 
-            callPluginMethod("changeCapabilities", ctx, capsToAdd, capsToRemove, auth);
-
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
             oxcox.changeCapabilities(ctx, capsToAdd, capsToRemove, auth);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
         final CacheService cacheService = AdminDaemon.getService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context, CacheService.class);
         if (null != cacheService) {
             try {
-                Cache jcs = cacheService.getCache("CapabilitiesContext");
-                final Serializable key = Integer.valueOf(ctx.getId().intValue());
-                jcs.remove(key);
-            } catch (final OXException e) {
-                log.error(e.getMessage(), e);
+                try {
+                    final Cache jcs = cacheService.getCache("CapabilitiesContext");
+                    final Serializable key = Integer.valueOf(ctx.getId().intValue());
+                    jcs.remove(key);
+                } catch (final OXException e) {
+                    log.error("", e);
+                }
+                try {
+                    final Cache jcs = cacheService.getCache("Capabilities");
+                    jcs.invalidateGroup(ctx.getId().toString());
+                } catch (final OXException e) {
+                    log.error("", e);
+                }
             } finally {
                 AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
             }
         }
+
+        final EventSystemService eventSystemService = AdminServiceRegistry.getInstance().getService(EventSystemService.class);
+        if (null != eventSystemService) {
+            try {
+                final Event event = new Event(ProviosioningEventConstants.TOPIC_CONTEXT_UPDATE);
+                event.setProperty(ProviosioningEventConstants.PROP_CONTEXT_ID, ctx.getId());
+                eventSystemService.publish(event);
+            } catch (final Exception e) {
+                log.warn("Could not distribute context event.", e);
+            }
+        }
     }
 
     @Override
@@ -247,7 +264,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
             final InvalidDataException invalidDataException = new InvalidDataException("Context is invalid");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
         validateloginmapping(ctx);
@@ -259,7 +276,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (NoSuchObjectException e) {
             throw new NoSuchContextException(e);
         }
-        log.debug(ctx);
+        log.debug(ctx.toString());
 
         Context backup_ctx = null; // used for invalidating old login mappings in the cache
 
@@ -276,7 +293,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             if(ctx.getFilestoreId()!=null) {
                 if(!tool.existsStore(ctx.getFilestoreId().intValue())){
                     final InvalidDataException inde = new InvalidDataException("No such filestore with id "+ctx.getFilestoreId());
-                    log.error(inde.getMessage(),inde);
+                    log.error("",inde);
                     throw inde;
                 }
             }
@@ -287,10 +304,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             backup_ctx = oxcox.getData(ctx);
             oxcox.change(ctx);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -304,7 +321,18 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
         } catch (final OXException e) {
-            log.error("Error invalidating cached infos of context "+ctx.getId()+" in context storage",e);
+            log.error("Error invalidating cached infos of context {} in context storage", ctx.getId(),e);
+        }
+
+        final EventSystemService eventSystemService = AdminServiceRegistry.getInstance().getService(EventSystemService.class);
+        if (null != eventSystemService) {
+            try {
+                final Event event = new Event(ProviosioningEventConstants.TOPIC_CONTEXT_UPDATE);
+                event.setProperty(ProviosioningEventConstants.PROP_CONTEXT_ID, ctx.getId());
+                eventSystemService.publish(event);
+            } catch (final Exception e) {
+                log.warn("Could not distribute context event.", e);
+            }
         }
     }
 
@@ -329,10 +357,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw e3;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + admin_user + " - "+ access_combination_name
-                + " - "+ auth);
-        }
+        log.debug("{} - {} - {} - {}", ctx, admin_user, access_combination_name, auth);
 
         final UserModuleAccess access = ClientAdminThread.cache.getNamedAccessCombination(access_combination_name.trim());
         if(access==null){
@@ -367,7 +392,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(ctx);
         } catch (final InvalidDataException e) {
             final InvalidDataException e1 = new InvalidDataException("Context is null");
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         }
 
@@ -379,7 +404,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (NoSuchObjectException e) {
             throw new NoSuchContextException(e);
         }
-        log.debug(ctx);
+        log.debug(ctx.toString());
         try {
             if (!tool.existsContext(ctx)) {
                 throw new NoSuchContextException();
@@ -400,13 +425,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             oxcox.delete(ctx);
             basicAuthenticator.removeFromAuthCache(ctx);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -416,19 +441,32 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final CacheService cacheService = AdminDaemon.getService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context, CacheService.class);
             if (null != cacheService) {
                 try {
-                    final Cache cache = cacheService.getCache("MailAccount");
+                    Cache cache = cacheService.getCache("MailAccount");
                     cache.clear();
+                    cache = cacheService.getCache("Capabilities");
+                    cache.invalidateGroup(ctx.getId().toString());
                 } catch (final OXException e) {
-                    log.error(e.getMessage(), e);
+                    log.error("", e);
                 } finally {
                     AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
                 }
             }
             pool.resetPoolMappingForContext(contextID);
         } catch (final OXException e) {
-            log.error("Error invalidating context " + ctx.getId() + " in ox context storage", e);
+            log.error("Error invalidating context {} in ox context storage", ctx.getId(), e);
         } catch (PoolException e) {
-            log.info("Could not reset PoolMapping for context " + ctx.getId() + " while deleting it. Should not have been mapped then.");
+            log.info("Could not reset PoolMapping for context {} while deleting it. Should not have been mapped then.", ctx.getId());
+        }
+
+        final EventSystemService eventSystemService = AdminServiceRegistry.getInstance().getService(EventSystemService.class);
+        if (null != eventSystemService) {
+            try {
+                final Event event = new Event(ProviosioningEventConstants.TOPIC_CONTEXT_DELETE);
+                event.setProperty(ProviosioningEventConstants.PROP_CONTEXT_ID, ctx.getId());
+                eventSystemService.publish(event);
+            } catch (final Exception e) {
+                log.warn("Could not distribute context event.", e);
+            }
         }
     }
 
@@ -455,7 +493,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (NoSuchObjectException e) {
             throw new NoSuchContextException(e);
         }
-        log.debug(ctx + " - " + reason);
+        log.debug("{} - {}", ctx, reason);
         try {
             if (!tool.existsContext(ctx)) {
                 throw new NoSuchContextException();
@@ -470,26 +508,26 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
             oxcox.disable(ctx, reason);
-            log.info("Context " + ctx.getId() + " successfully disabled");
+            log.info("Context {} successfully disabled", ctx.getId());
 
             try {
                 ContextStorage.getInstance().invalidateContext(ctx.getId().intValue());
-                log.info("Context " + ctx.getId() + " successfully invalidated");
+                log.info("Context {} successfully invalidated", ctx.getId());
             } catch (final OXException e) {
-                log.error("Error invalidating context "+ctx.getId()+" in ox context storage",e);
+                log.error("Error invalidating context {} in ox context storage", ctx.getId(),e);
             }
 
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         /*} catch (final NoSuchReasonException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;*/
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final OXContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -512,7 +550,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         new BasicAuthenticator(context).doAuthentication(auth);
 
         final int reason_id = reason.getId();
-        log.debug("" + reason_id);
+        log.debug("{}", reason_id);
         try {
 //            if (!tool.existsReason(reason_id)) {
 //                throw new NoSuchReasonException();
@@ -524,10 +562,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 callPluginMethod("disableAll", auth);
             }
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
 //        } catch (final NoSuchReasonException e) {
-//            log.error(e.getMessage(), e);
+//            log.error("", e);
 //            throw e;
         }
 
@@ -540,7 +578,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 final Cache cache = cacheService.getCache("Context");
                 cache.clear();
             } catch (final OXException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
             } finally {
                 AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
             }
@@ -555,7 +593,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
             final InvalidDataException invalidDataException = new InvalidDataException("Context is null");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
 
@@ -566,7 +604,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (NoSuchObjectException e) {
             throw new NoSuchContextException(e);
         }
-        log.debug(ctx);
+        log.debug(ctx.toString());
         try {
             if (!tool.existsContext(ctx)) {
                 throw new NoSuchContextException();
@@ -575,17 +613,17 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
             oxcox.enable(ctx);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
         try {
             ContextStorage.getInstance().invalidateContext(ctx.getId().intValue());
         } catch (final OXException e) {
-            log.error("Error invalidating context "+ctx.getId()+" in ox context storage",e);
+            log.error("Error invalidating context {} in ox context storage", ctx.getId(),e);
         }
     }
 
@@ -602,7 +640,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 callPluginMethod("enableAll", auth);
             }
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -615,7 +653,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 final Cache cache = cacheService.getCache("Context");
                 cache.clear();
             } catch (final OXException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
             } finally {
                 AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
             }
@@ -647,13 +685,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 } catch (NoSuchObjectException e) {
                     throw new NoSuchContextException(e);
                 }
-                log.debug(ctx);
+                log.debug(ctx.toString());
                 try {
                     if (!tool.existsContext(ctx)) {
                         throw new NoSuchContextException();
                     }
                 } catch (final NoSuchContextException e) {
-                    log.error(e.getMessage(), e);
+                    log.error("", e);
                     throw e;
                 }
             }
@@ -677,12 +715,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                     }
                 }
             } catch (final StorageException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw e;
             }
             return retval.toArray(new Context[retval.size()]);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -699,12 +737,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(search_pattern);
         } catch (final InvalidDataException e) {
             final InvalidDataException invalidDataException = new InvalidDataException("Search pattern is null");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
         new BasicAuthenticator(context).doAuthentication(auth);
 
-        log.debug("" + search_pattern);
+        log.debug("{}", search_pattern);
 
         try {
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
@@ -724,9 +762,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                             if (null != property && property.toString().equalsIgnoreCase("oxcontext")) {
                                 final OXContextPluginInterface oxctx = (OXContextPluginInterface) this.context.getService(servicereference);
                                 //TODO: Implement check for contextadmin here
-                                if (log.isDebugEnabled()) {
-                                    log.debug("Calling list for plugin: " + bundlename);
-                                }
+                                    log.debug("Calling list for plugin: {}", bundlename);
                                 try {
                                     filter = oxctx.filter(auth);
                                     if (null != filter) {
@@ -737,7 +773,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                                         loaderFilter.add(loader);
                                     }
                                 } catch (final PluginException e) {
-                                    log.error("Error while calling method list of plugin " + bundlename,e);
+                                    log.error("Error while calling method list of plugin {}", bundlename,e);
                                     throw new StorageException(e.getCause());
                                 }
                             }
@@ -748,7 +784,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             return oxcox.listContext(search_pattern, contextFilter, loaderFilter);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -769,7 +805,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(db);
         } catch (final InvalidDataException e) {
             final InvalidDataException invalidDataException = new InvalidDataException("Database is null");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
         new BasicAuthenticator().doAuthentication(auth);
@@ -779,7 +815,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (NoSuchObjectException e) {
             throw new NoSuchDatabaseException(e);
         }
-        log.debug(db);
+        log.debug(db.toString());
         try {
             if( !tool.existsDatabase(db.getId()) ) {
                 throw new NoSuchDatabaseException();
@@ -796,7 +832,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
             return retval.toArray(new Context[retval.size()]);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -809,12 +845,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(filestore.getId());
         } catch (final InvalidDataException e) {
             final InvalidDataException invalidDataException = new InvalidDataException("Filestore is null");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
         new BasicAuthenticator().doAuthentication(auth);
 
-        log.debug(filestore);
+        log.debug(filestore.toString());
         try {
             if( !tool.existsStore(filestore.getId()) ) {
                 throw new NoSuchFilestoreException();
@@ -830,7 +866,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
             return retval.toArray(new Context[retval.size()]);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -868,9 +904,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new StorageException(e);
         }
         final int reason_id = reason.getId();
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + db + " - " + reason_id);
-        }
+            log.debug("{} - {} - {}", ctx, db, reason_id);
         try {
             /*if (!tool.existsReason(reason_id)) {
                 // FIXME: Util in context???
@@ -903,13 +937,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             return TaskManager.getInstance().addJob(ddm, "movedatabase", "move context " + ctx.getIdAsString() + " to database " + dbid, ctx.getId());
         } catch (final OXContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -934,13 +968,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
         Context retval = null;
 
-        log.debug(ctx+ " - " + dst_filestore);
+        log.debug("{} - {}", ctx, dst_filestore);
 
         final OXContextStorageInterface oxcox;
         try {
             oxcox = OXContextStorageInterface.getInstance();
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new OXContextException(e);
         }
         try {
@@ -1001,16 +1035,16 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
         } catch (final URISyntaxException e) {
             final StorageException storageException = new StorageException(e);
-            log.error(storageException.getMessage(), storageException);
+            log.error("", storageException);
             throw storageException;
         } catch (final NoSuchFilestoreException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         /*} catch (final NoSuchReasonException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;*/
         } catch (final OXContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             oxcox.enable(ctx);
@@ -1041,13 +1075,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             try {
                 ret = (Context)callPluginMethod("postCreate", ret, admin_user, createaccess, auth);
             } catch(final StorageException e) {
-                log.error(e.getMessage(),e);
+                log.error("",e);
                 // callPluginMethod delete may fail here for what ever reason.
                 // this must not prevent us from cleaning up the rest
                 try {
                     callPluginMethod("delete", ctx, auth);
                 } catch (final Exception e1) {
-                    log.error(e.getMessage(), e);
+                    log.error("", e);
                 }
                 oxcox.delete(ret);
                 throw e;
@@ -1101,7 +1135,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new NoSuchContextException(e);
         }
 
-        log.debug(ctx+" - "+access);
+        log.debug("{} - {}", ctx, access);
 
         try {
             if (!tool.existsContext(ctx)) {
@@ -1125,10 +1159,20 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
             }
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
+        final EventSystemService eventSystemService = AdminServiceRegistry.getInstance().getService(EventSystemService.class);
+        if (null != eventSystemService) {
+            try {
+                final Event event = new Event(ProviosioningEventConstants.TOPIC_CONTEXT_UPDATE);
+                event.setProperty(ProviosioningEventConstants.PROP_CONTEXT_ID, ctx.getId());
+                eventSystemService.publish(event);
+            } catch (final Exception e) {
+                log.warn("Could not distribute context event.", e);
+            }
+        }
     }
 
     @Override
@@ -1155,7 +1199,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new NoSuchContextException(e);
         }
 
-        log.debug(ctx+" - "+access_combination_name);
+        log.debug("{} - {}", ctx, access_combination_name);
 
         try {
 
@@ -1186,10 +1230,20 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
             }
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
+        final EventSystemService eventSystemService = AdminServiceRegistry.getInstance().getService(EventSystemService.class);
+        if (null != eventSystemService) {
+            try {
+                final Event event = new Event(ProviosioningEventConstants.TOPIC_CONTEXT_UPDATE);
+                event.setProperty(ProviosioningEventConstants.PROP_CONTEXT_ID, ctx.getId());
+                eventSystemService.publish(event);
+            } catch (final Exception e) {
+                log.warn("Could not distribute context event.", e);
+            }
+        }
     }
 
     /**
@@ -1205,7 +1259,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (final InvalidDataException e1) {
             final InvalidDataException invalidDataException
                 = new InvalidDataException("Context is invalid");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
         new BasicAuthenticator(context).doAuthentication(auth);
@@ -1216,7 +1270,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new NoSuchContextException(e);
         }
 
-        log.debug(ctx);
+        log.debug(ctx.toString());
 
         if (!tool.existsContext(ctx)) {
             throw new NoSuchContextException();
@@ -1227,14 +1281,14 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             callPluginMethod("downgrade", ctx, auth);
             oxcox.downgrade(ctx);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
         try {
             ContextStorage.getInstance().invalidateContext(ctx.getId().intValue());
         } catch (final OXException e) {
-            log.error("Error invalidating context "+ctx.getId()+" in ox context storage",e);
+            log.error("Error invalidating context {} in ox context storage", ctx.getId(),e);
         }
     }
 
@@ -1248,7 +1302,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
             final InvalidDataException invalidDataException = new InvalidDataException("Context is invalid");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
 
@@ -1260,7 +1314,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new NoSuchContextException(e);
         }
 
-        log.debug(ctx);
+        log.debug(ctx.toString());
 
         try {
             if (!tool.existsContext(ctx)) {
@@ -1273,7 +1327,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             return ClientAdminThread.cache.getNameForAccessCombination(oxu.getModuleAccess(ctx, tool.getAdminForContext(ctx)));
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -1287,7 +1341,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
             final InvalidDataException invalidDataException = new InvalidDataException("Context is invalid");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
 
@@ -1299,7 +1353,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw new NoSuchContextException(e);
         }
 
-        log.debug(ctx);
+        log.debug(ctx.toString());
 
         try {
             if (!tool.existsContext(ctx)) {
@@ -1311,7 +1365,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final OXUserStorageInterface oxu = OXUserStorageInterface.getInstance();
             return oxu.getModuleAccess(ctx, tool.getAdminForContext(ctx));
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -1337,14 +1391,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                         if (null != property && property.toString().equalsIgnoreCase("oxcontext")) {
                             extensionsFound = true;
                             final OXContextPluginInterface oxctx = (OXContextPluginInterface) this.context.getService(servicereference);
-                            if (log.isDebugEnabled()) {
-                                log.debug("Calling getData for plugin: " + bundlename);
-                            }
+                                log.debug("Calling getData for plugin: {}", bundlename);
                             try {
                                 retval = oxctx.getData(ctxs, auth);
                                 addExtensionToContext(ctxs, retval, bundlename);
                             } catch (final PluginException e) {
-                                log.error("Error while calling method list of plugin " + bundlename,e);
+                                log.error("Error while calling method list of plugin {}", bundlename,e);
                                 throw new StorageException(e.getCause());
                             }
                         }
@@ -1379,7 +1431,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         try {
             callPluginMethod("getAdminId", ctx, auth);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -1402,7 +1454,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         try {
             callPluginMethod("exists", ctx, auth);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
