@@ -52,8 +52,6 @@ package com.openexchange.admin.tools;
 
 import java.util.concurrent.Callable;
 
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Database;
@@ -63,7 +61,7 @@ import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
 
 public class DatabaseDataMover implements Callable<Void> {
 
-    private final static Log log = LogFactory.getLog(DatabaseDataMover.class);
+    private final static org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(DatabaseDataMover.class);
 
     private Context ctx = null;
 
@@ -86,12 +84,12 @@ public class DatabaseDataMover implements Callable<Void> {
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
             oxcox.moveDatabaseContext(ctx, db, reason_id);
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             // Because the client side only knows of the exceptions defined in the core we have
             // to throw the trace as string
             throw new StorageException(e.toString());
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
         return null;
