@@ -54,9 +54,8 @@ import java.sql.DatabaseMetaData;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.text.MessageFormat;
 import java.util.Vector;
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 
 /**
  *
@@ -64,7 +63,7 @@ import com.openexchange.log.LogFactory;
  */
 public class DataFetcherMysql implements DataFetcher{
 
-    private final Log log = LogFactory.getLog(DataFetcherMysql.class);
+    private final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(DataFetcherMysql.class);
 
     private Connection dbConnection = null;
 
@@ -141,7 +140,7 @@ public class DataFetcherMysql implements DataFetcher{
         try{
             prep = this.dbConnection.prepareStatement(sb.toString());
             prep.setObject(1,getColumnMatchObject(),getColumnMatchType());
-            log.debug("######## "+sb.toString());
+            log.debug("######## {}", sb);
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
                 TableRowObject tro = new TableRowObject();
@@ -176,7 +175,7 @@ public class DataFetcherMysql implements DataFetcher{
 
 //        if(to.getDataRowCount()>0){
 //            tableObjects.add(to);
-//            //log.debug(to.getName() +" "+to.getDataRowCount());
+//            //log.debug("{} {}", to.getName(), to.getDataRowCount());
 //        }
 
 
@@ -217,7 +216,7 @@ public class DataFetcherMysql implements DataFetcher{
                 tableObjects.add(to);
             }
         }
-        log.debug("####### Found -> "+tableObjects.size()+" tables");
+        log.debug("####### Found -> {} tables", tableObjects.size());
 
         return tableObjects;
     }
@@ -268,15 +267,15 @@ public class DataFetcherMysql implements DataFetcher{
             String table_name = to.getName();
             //ResultSet table_references = dbmetadata.getCrossReference("%",null,table_name,getCatalogName(),null,getCatalogName());
             ResultSet table_references = dbmetadata.getImportedKeys(getCatalogName(),null,table_name);
-            log.debug("Table "+table_name+" has pk reference to table-column:");
+            log.debug("Table {} has pk reference to table-column:", table_name);
             while(table_references.next()){
                 String pk = table_references.getString("PKTABLE_NAME");
                 String pkc = table_references.getString("PKCOLUMN_NAME");
-                log.debug("--> Table: "+pk+" column ->"+pkc);
+                log.debug("--> Table: {} column ->{}", pk, pkc);
                 to.addCrossReferenceTable(pk);
                 int pos_in_list = tableListContainsObject(pk);
                 if(pos_in_list!=-1){
-                    log.debug("Found referenced by "+table_name+"<->"+pk+"->"+pkc);
+                    log.debug("Found referenced by {}<->{}->{}", table_name, pk, pkc);
                     TableObject edit_me = tableObjects.get(pos_in_list);
                     edit_me.addReferencedBy(table_name);
                 }
@@ -312,7 +311,7 @@ public class DataFetcherMysql implements DataFetcher{
             for(int a = 0;a<unsorted.size();a++){
                 TableObject to = unsorted.get(a);
                 if(!to.hasCrossReferences()){
-                    //log.error("removing "+to.getName());
+                    //log.error("removing {}", to.getName());
                     nasty_order.add(to);
                     // remove object from list and sort the references new
                     removeAndSortNew(unsorted,to);
