@@ -54,13 +54,9 @@ import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
-
 import com.openexchange.admin.daemons.AdminDaemon;
 import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.plugins.OXGroupPluginInterface;
@@ -103,7 +99,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 
     private AdminCache cache = null;
 
-    private final Log log = LogFactory.getLog(this.getClass());
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXGroup.class);
 
     private PropertyHandler prop = null;
 
@@ -119,15 +115,13 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             oxGroup = OXGroupStorageInterface.getInstance();
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
         this.context = context;
         cache = ClientAdminThread.cache;
         prop = cache.getProperties();
-        if (log.isInfoEnabled()) {
-            log.info("Class loaded: " + this.getClass().getName());
-        }
+        log.info("Class loaded: {}", this.getClass().getName());
         basicauth = new BasicAuthenticator();
     }
 
@@ -144,7 +138,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -154,10 +148,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
             throw new NoSuchGroupException(e);
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp + " - " + Arrays.toString(members)
-                + " - " + auth);
-        }
+            log.debug("{} - {} - {} - {}", ctx, grp, Arrays.toString(members), auth);
 
         checkContextAndSchema(ctx);
 
@@ -180,7 +171,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 throw new InvalidDataException("Member already exists in group");
             }
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -197,7 +188,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                     cache.remove(cacheService.newCacheKey(contextId, user.getId()));
 	            }
 	        } catch (final OXException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
             } finally {
 	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
 	        }
@@ -218,13 +209,11 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp + " - " + auth);
-        }
+            log.debug("{} - {} - {}", ctx, grp, auth);
 
         try {
             checkContextAndSchema(ctx);
@@ -288,7 +277,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         }
                     }
     	        } catch (final OXException e) {
-    	            log.error(e.getMessage(), e);
+    	            log.error("", e);
     	        } finally {
     	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
     	        }
@@ -297,25 +286,25 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 
         } catch (final EnforceableDataObjectException e2) {
             final InvalidDataException invalidDataException = new InvalidDataException(e2.getMessage());
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final InvalidDataException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         } catch (final NoSuchUserException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchGroupException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -330,12 +319,10 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         if (null != property && property.toString().equalsIgnoreCase("oxgroup")) {
                             final OXGroupPluginInterface oxgroup = (OXGroupPluginInterface) this.context.getService(servicereference);
                             try {
-                                if (log.isDebugEnabled()) {
-                                    log.debug("Calling change for plugin: " + bundlename);
-                                }
+                                log.debug("Calling change for plugin: {}", bundlename);
                                 oxgroup.change(ctx, grp, auth);
                             } catch (final PluginException e) {
-                                log.error("Error while calling change for plugin: " + bundlename, e);
+                                log.error("Error while calling change for plugin: {}", bundlename, e);
                                 throw new StorageException(e);
                             }
                         }
@@ -361,13 +348,11 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e2) {
-            log.error(e2.getMessage(), e2);
+            log.error("", e2);
             throw e2;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, grp, auth);
 
         checkContextAndSchema(ctx);
 
@@ -397,10 +382,10 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 }
             }
         } catch (final InvalidDataException e2) {
-            log.error(e2.getMessage(), e2);
+            log.error("", e2);
             throw e2;
         } catch (final NoSuchUserException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (EnforceableDataObjectException e) {
             throw new InvalidDataException(e.getMessage());
@@ -426,10 +411,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                             final OXGroupPluginInterface oxgroup = (OXGroupPluginInterface) this.context
                                     .getService(servicereference);
                             try {
-                                if (log.isDebugEnabled()) {
-                                    log.debug("Calling create for plugin: "
-                                            + bundlename);
-                                }
+                                log.debug("Calling create for plugin: {}", bundlename);
                                 oxgroup.create(ctx, grp, auth);
                                 interfacelist.add(oxgroup);
                             } catch (final PluginException e) {
@@ -477,7 +459,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         cache.remove(cacheService.newCacheKey(ctx.getId().intValue(), member_id));
                     }
     	        } catch (final OXException e) {
-    	            log.error(e.getMessage(), e);
+    	            log.error("", e);
     	        } finally {
     	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
     	        }
@@ -498,7 +480,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         cache.remove(cacheService.newCacheKey(ctx.getId().intValue(), member_id));
                     }
     	        } catch (final OXException e) {
-    	            log.error(e.getMessage(), e);
+    	            log.error("", e);
     	        } finally {
     	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
     	        }
@@ -557,31 +539,30 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 }
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug(ctx + " - " + Arrays.toString(grp) + " - " + auth);
-            }
+            log.debug("{} - {} - {}", ctx, Arrays.toString(grp), auth);
+
             checkContextAndSchema(ctx);
 
             if (!tool.existsGroup(ctx, grp)) {
                 throw new NoSuchGroupException("No such group");
             }
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final InvalidCredentialsException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchGroupException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -607,10 +588,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                             final OXGroupPluginInterface oxgroup = (OXGroupPluginInterface) this.context
                                     .getService(servicereference);
                             try {
-                                if (log.isDebugEnabled()) {
-                                    log.debug("Calling delete for plugin: "
-                                            + bundlename);
-                                }
+                                log.debug("Calling delete for plugin: {}", bundlename);
                                 oxgroup.delete(ctx, grp, auth);
                                 interfacelist.add(oxgroup);
                             } catch (final PluginException e) {
@@ -648,7 +626,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         }
                     }
     	        } catch (final OXException e) {
-    	            log.error(e.getMessage(), e);
+    	            log.error("", e);
     	        } finally {
     	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
     	        }
@@ -656,7 +634,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
             // END OF JCS
 
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -678,7 +656,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -690,9 +668,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 
         final int grp_id = grp.getId().intValue();
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp_id + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, grp_id, auth);
         checkContextAndSchema(ctx);
 
         if (!tool.existsGroup(ctx, grp_id)) {
@@ -716,10 +692,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                                         "oxgroup")) {
                             final OXGroupPluginInterface oxgroupplugin = (OXGroupPluginInterface) this.context
                                     .getService(servicereference);
-                            if (log.isDebugEnabled()) {
-                                log.debug("Calling getData for plugin: "
-                                        + bundlename);
-                            }
+                            log.debug("Calling getData for plugin: {}", bundlename);
                             retgrp = oxgroupplugin.get(ctx, retgrp, auth);
                         }
                     }
@@ -745,9 +718,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 
         try {
             basicauth.doAuthentication(auth, ctx);
-            if (log.isDebugEnabled()) {
-                log.debug(ctx + " - " + Arrays.toString(groups) + " - " + auth);
-            }
+            log.debug("{} - {} - {}", ctx, Arrays.toString(groups), auth);
             checkContextAndSchema(ctx);
 
             // resolv group id/username
@@ -779,7 +750,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 }
             }
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -804,10 +775,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                                         "oxgroup")) {
                             final OXGroupPluginInterface oxgroupplugin = (OXGroupPluginInterface) this.context
                                     .getService(servicereference);
-                            if (log.isDebugEnabled()) {
-                                log.debug("Calling get for plugin: "
-                                        + bundlename);
-                            }
+                            log.debug("Calling get for plugin: {}", bundlename);
                             for (Group group : retval) {
                                 group = oxgroupplugin.get(ctx, group, auth);
                             }
@@ -826,9 +794,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
             InvalidDataException, DatabaseUpdateException {
         auth = auth == null ? new Credentials("","") : auth;
         basicauth.doAuthentication(auth, ctx);
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + auth);
-        }
+        log.debug("{} - {}", ctx, auth);
         checkContextAndSchema(ctx);
 
         try {
@@ -856,7 +822,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -867,9 +833,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         }
         final int grp_id = grp.getId().intValue();
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp_id + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, grp_id, auth);
 
         checkContextAndSchema(ctx);
 
@@ -897,13 +861,11 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + pattern + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, pattern, auth);
 
         checkContextAndSchema(ctx);
 
@@ -935,13 +897,11 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + usr + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, usr, auth);
 
         checkContextAndSchema(ctx);
 
@@ -968,17 +928,14 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
         try {
             doNullCheck(grp, members);
         } catch (final InvalidDataException e3) {
-            log
-                    .error(
-                            "One of the given arguments for removeMember is null",
-                            e3);
+            log.error("One of the given arguments for removeMember is null", e3);
             throw e3;
         }
 
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -988,10 +945,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
             throw new NoSuchGroupException(e);
         }
         final int grp_id = grp.getId().intValue();
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + grp_id + " - " + Arrays.toString(members)
-                + " - " + auth);
-        }
+        log.debug("{} - {} - {} - {}", ctx, grp_id, Arrays.toString(members), auth);
 
         checkContextAndSchema(ctx);
 
@@ -1020,7 +974,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 	                cache.remove(cacheService.newCacheKey(ctx.getId().intValue(), user.getId()));
 	            }
 	        } catch (final OXException e) {
-	            log.error(e.getMessage(), e);
+	            log.error("", e);
 	        } finally {
 	        	AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
 	        }
