@@ -52,7 +52,6 @@ package com.openexchange.admin.rmi.impl;
 import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Arrays;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
@@ -77,13 +76,12 @@ import com.openexchange.admin.storage.interfaces.OXResourceStorageInterface;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.GenericChecks;
 import com.openexchange.admin.tools.PropertyHandler;
-import com.openexchange.log.LogFactory;
 
 public class OXResource extends OXCommonImpl implements OXResourceInterface{
 
     private static final long serialVersionUID = -7012370962672596682L;
 
-    private static final Log log = LogFactory.getLog(OXResource.class);
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXResource.class);
 
     private final BasicAuthenticator basicauth;
 
@@ -100,15 +98,13 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
         try {
             oxRes = OXResourceStorageInterface.getInstance();
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new RemoteException(e.getMessage());
         }
         this.context = context;
         cache = ClientAdminThread.cache;
         prop = cache.getProperties();
-        if (log.isInfoEnabled()) {
-            log.info("Class loaded: " + this.getClass().getName());
-        }
+        log.info("Class loaded: {}", this.getClass().getName());
         basicauth = new BasicAuthenticator();
     }
 
@@ -119,20 +115,18 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             doNullCheck(res);
         } catch (final InvalidDataException e3) {
             final InvalidDataException invalidDataException = new InvalidDataException("One of the given arguments for change is null");
-            log.error(invalidDataException.getMessage(), invalidDataException);
+            log.error("", invalidDataException);
             throw invalidDataException;
         }
 
         try {
             basicauth.doAuthentication(auth,ctx);
         } catch (final InvalidDataException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + res + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, res, auth);
 
         try {
             try {
@@ -175,19 +169,19 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                 throw new InvalidDataException("Invalid email address");
             }
         } catch (final InvalidDataException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         } catch (final StorageException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         } catch (final DatabaseUpdateException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         } catch (final NoSuchContextException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         } catch (final NoSuchResourceException e1) {
-            log.error(e1.getMessage(), e1);
+            log.error("", e1);
             throw e1;
         }
 
@@ -204,12 +198,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                         if (null != property && property.toString().equalsIgnoreCase("oxresource")) {
                             final OXResourcePluginInterface oxresource = (OXResourcePluginInterface) this.context.getService(servicereference);
                             try {
-                                if (log.isInfoEnabled()) {
-                                    log.info("Calling change for plugin: " + bundlename);
-                                }
+                                log.info("Calling change for plugin: {}", bundlename);
                                 oxresource.change(ctx, res, auth);
                             } catch (final PluginException e) {
-                                log.error("Error while calling change for plugin: " + bundlename, e);
+                                log.error("Error while calling change for plugin: {}", bundlename, e);
                                 throw new StorageException(e);
                             }
                         }
@@ -233,13 +225,11 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
        try {
            basicauth.doAuthentication(auth,ctx);
        } catch( final InvalidDataException e) {
-           log.error(e.getMessage(), e);
+           log.error("", e);
            throw e;
        }
 
-       if (log.isDebugEnabled()) {
-           log.debug(ctx + " - " + res + " - " + auth);
-       }
+           log.debug("{} - {} - {}", ctx, res, auth);
 
        checkContextAndSchema(ctx);
 
@@ -274,7 +264,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                 throw new InvalidDataException("Invalid email address");
             }
         } catch (final InvalidDataException e2) {
-            log.error(e2.getMessage(), e2);
+            log.error("", e2);
             throw e2;
         } catch (EnforceableDataObjectException e) {
             throw new InvalidDataException(e.getMessage());
@@ -295,19 +285,17 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                        if (null != property && property.toString().equalsIgnoreCase("oxresource")) {
                            final OXResourcePluginInterface oxresource = (OXResourcePluginInterface) this.context.getService(servicereference);
                            try {
-                               if (log.isDebugEnabled()) {
-                                   log.debug("Calling create for plugin: " + bundlename);
-                               }
+                                   log.debug("Calling create for plugin: {}", bundlename);
                                oxresource.create(ctx, res, auth);
                                interfacelist.add(oxresource);
                            } catch (final PluginException e) {
-                               log.error("Error while calling create for plugin: " + bundlename, e);
+                               log.error("Error while calling create for plugin: {}", bundlename, e);
                                log.info("Now doing rollback for everything until now...");
                                for (final OXResourcePluginInterface oxresourceinterface : interfacelist) {
                                    try {
                                        oxresourceinterface.delete(ctx, res, auth);
                                    } catch (final PluginException e1) {
-                                       log.error("Error doing rollback for plugin: " + bundlename, e1);
+                                       log.error("Error doing rollback for plugin: {}", bundlename, e1);
                                    }
                                }
                                try {
@@ -344,30 +332,28 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             } catch (NoSuchObjectException e) {
                 throw new NoSuchResourceException(e);
             }
-            if (log.isDebugEnabled()) {
-                log.debug(ctx + " - " + res + " - " + auth);
-            }
+                log.debug("{} - {} - {}", ctx, res, auth);
             checkContextAndSchema(ctx);
             if (!tool.existsResource(ctx, res.getId())) {
                 throw new NoSuchResourceException("Resource with this id does not exist");
             }
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final InvalidCredentialsException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchContextException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final NoSuchResourceException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
         final ArrayList<OXResourcePluginInterface> interfacelist = new ArrayList<OXResourcePluginInterface>();
@@ -387,13 +373,11 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                         if (null != property && property.toString().equalsIgnoreCase("oxresource")) {
                             final OXResourcePluginInterface oxresource = (OXResourcePluginInterface) this.context.getService(servicereference);
                             try {
-                                if (log.isInfoEnabled()) {
-                                    log.info("Calling delete for plugin: " + bundlename);
-                                }
+                                log.info("Calling delete for plugin: {}", bundlename);
                                 oxresource.delete(ctx, res, auth);
                                 interfacelist.add(oxresource);
                             } catch (final PluginException e) {
-                                log.error("Error while calling delete for plugin: " + bundlename, e);
+                                log.error("Error while calling delete for plugin: {}", bundlename, e);
                                 throw new StorageException(e);
                             }
                         }
@@ -418,7 +402,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
         try {
             basicauth.doAuthentication(auth,ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -430,9 +414,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
 
         final int resource_id = res.getId().intValue();
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + resource_id + " - " + auth);
-        }
+        log.debug("{} - {} - {}", ctx, resource_id, auth);
 
         checkContextAndSchema(ctx);
 
@@ -452,9 +434,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                         final Object property = servicereference.getProperty("name");
                         if (null != property && property.toString().equalsIgnoreCase("oxresource")) {
                             final OXResourcePluginInterface oxresourceplugin = (OXResourcePluginInterface) this.context.getService(servicereference);
-                            if (log.isInfoEnabled()) {
-                                log.info("Calling getData for plugin: " + bundlename);
-                            }
+                            log.info("Calling getData for plugin: {}", bundlename);
                             retres = oxresourceplugin.get(ctx, retres, auth);
                         }
                     }
@@ -478,9 +458,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
         try {
             basicauth.doAuthentication(auth,ctx);
 
-            if (log.isDebugEnabled()) {
-                log.debug(ctx + " - " + Arrays.toString(resources) + " - " + auth);
-            }
+                log.debug("{} - {} - {}", ctx, Arrays.toString(resources), auth);
 
             checkContextAndSchema(ctx);
 
@@ -505,7 +483,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                 }
             }
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
@@ -527,9 +505,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
                         final Object property = servicereference.getProperty("name");
                         if (null != property && property.toString().equalsIgnoreCase("oxresource")) {
                             final OXResourcePluginInterface oxresourceplugin = (OXResourcePluginInterface) this.context.getService(servicereference);
-                            if (log.isInfoEnabled()) {
-                                log.info("Calling get for plugin: " + bundlename);
-                            }
+                            log.info("Calling get for plugin: {}", bundlename);
                             for (Resource resource : retval) {
                                 resource = oxresourceplugin.get(ctx, resource, auth);
                             }
@@ -558,13 +534,11 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
 
             basicauth.doAuthentication(auth,ctx);
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug(ctx + " - " + pattern + " - " + auth);
-        }
+            log.debug("{} - {} - {}", ctx, pattern, auth);
 
         checkContextAndSchema(ctx);
 
